/*
 * ArrayOps.cs --
 *
 * Copyright (c) 2007-2012 by Joe Mistachkin.  All rights reserved.
 *
 * See the file "license.terms" for information on usage and redistribution of
 * this file, and for a DISCLAIMER OF ALL WARRANTIES.
 *
 * RCS: @(#) $Id: $
 */

using System;
using System.Text;
using Eagle._Attributes;
using Eagle._Encodings;

namespace Eagle._Components.Private
{
    [ObjectId("e6709468-95a4-405e-8c9c-e0dbd1aa3a88")]
    internal static class ArrayOps
    {
        private static Encoding oneByteEncoding = OneByteEncoding.OneByte;
        private static Encoding twoByteEncoding = TwoByteEncoding.TwoByte;

        ///////////////////////////////////////////////////////////////////////

        private static bool HasTwoByteCharacter(
            string value,
            ref byte[] bytes
            )
        {
            if (String.IsNullOrEmpty(value))
                return false;

            if (twoByteEncoding == null)
                return false;

            bytes = twoByteEncoding.GetBytes(value);

            if (bytes == null)
                return false;

            int length = bytes.Length;

            if (length == 0)
                return false;

            if ((length % 2) != 0)
                return false;

            int zeroOffset = (bytes[0] != 0) ? 1 : 0;

            for (int index = 0; index < length; index += 2)
                if (bytes[index + zeroOffset] != 0)
                    return true;

            return false;
        }

        ///////////////////////////////////////////////////////////////////////

        public static string ToHexadecimalString(
            string value
            )
        {
            byte[] bytes = null;

            if (HasTwoByteCharacter(value, ref bytes))
                return ToHexadecimalString(bytes);
            else if (oneByteEncoding != null)
                return ToHexadecimalString(oneByteEncoding.GetBytes(value));
            else
                return null;
        }

        ///////////////////////////////////////////////////////////////////////

        public static string ToHexadecimalString(
            byte[] array
            )
        {
            if (array == null)
                return null;

            StringBuilder result = StringOps.NewStringBuilder();

            int length = array.Length;

            for (int index = 0; index < length; index++)
                result.Append(FormatOps.Hexadecimal(array[index], false));

            return result.ToString();
        }
    }
}
