/*
 * TclBuild.cs --
 *
 * Copyright (c) 2007-2012 by Joe Mistachkin.  All rights reserved.
 *
 * See the file "license.terms" for information on usage and redistribution of
 * this file, and for a DISCLAIMER OF ALL WARRANTIES.
 *
 * RCS: @(#) $Id: $
 */

using System;
using Eagle._Attributes;
using Eagle._Components.Public;
using Eagle._Constants;
using Eagle._Containers.Public;

namespace Eagle._Components.Private.Tcl
{
    [ObjectId("47d48277-9664-457a-bf97-9e4b73f4199d")]
#if TCL_WRAPPER
    public
#else
    internal
#endif
    sealed class TclBuild
    {
        public TclBuild()
        {
            // do nothing.
        }

        ///////////////////////////////////////////////////////////////////////

        public TclBuild(
            FindFlags flags,
            string fileName,
            Priority priority,
            OperatingSystemId operatingSystemId,
            Version patchLevel,
            ushort magic,
            bool threaded,
            bool debug
            )
        {
            this.flags = flags;
            this.fileName = fileName;
            this.priority = priority;
            this.operatingSystemId = operatingSystemId;
            this.patchLevel = patchLevel;
            this.magic = magic;
            this.threaded = threaded;
            this.debug = debug;

            //
            // NOTE: The version may only contain the major and minor parts.
            //
            this.version = (patchLevel != null) ?
                new Version(patchLevel.Major, patchLevel.Minor) : null;
        }

        ///////////////////////////////////////////////////////////////////////

        private FindFlags flags;
        public FindFlags Flags
        {
            get { return flags; }
            set { flags = value; }
        }

        ///////////////////////////////////////////////////////////////////////

        private string fileName;
        public string FileName
        {
            get { return fileName; }
            set { fileName = value; }
        }

        ///////////////////////////////////////////////////////////////////////

        private Priority priority;
        public Priority Priority
        {
            get { return priority; }
            set { priority = value; }
        }

        ///////////////////////////////////////////////////////////////////////

        private OperatingSystemId operatingSystemId;
        public OperatingSystemId OperatingSystemId
        {
            get { return operatingSystemId; }
            set { operatingSystemId = value; }
        }

        ///////////////////////////////////////////////////////////////////////

        private Version version;
        public Version Version
        {
            get { return version; }
            set { version = value; }
        }

        ///////////////////////////////////////////////////////////////////////

        private Version patchLevel;
        public Version PatchLevel
        {
            get { return patchLevel; }
            set { patchLevel = value; }
        }

        ///////////////////////////////////////////////////////////////////////

        private ushort magic;
        public ushort Magic
        {
            get { return magic; }
            set { magic = value; }
        }

        ///////////////////////////////////////////////////////////////////////

        private bool threaded;
        public bool Threaded
        {
            get { return threaded; }
            set { threaded = value; }
        }

        ///////////////////////////////////////////////////////////////////////

        private bool debug;
        public bool Debug
        {
            get { return debug; }
            set { debug = value; }
        }

        ///////////////////////////////////////////////////////////////////////

        public bool DefaultThreaded
        {
            get { return TclWrapper.IsBuildDefaultThreaded(this); }
        }

        ///////////////////////////////////////////////////////////////////////

        public bool MatchDebug
        {
            get { return debug == Build.Debug; }
        }

        ///////////////////////////////////////////////////////////////////////

        #region System.Object Overrides
        public override string ToString()
        {
            StringList list = new StringList();

            list.Add("flags");
            list.Add(flags.ToString());

            list.Add("fileName");
            list.Add(fileName);

            list.Add("priority");
            list.Add(priority.ToString());

            list.Add("operatingSystem");
            list.Add(operatingSystemId.ToString());

            list.Add("version");
            list.Add((version != null) ? version.ToString() : null);

            list.Add("patchLevel");
            list.Add((patchLevel != null) ? patchLevel.ToString() : null);

            list.Add("magic");
            list.Add(FormatOps.Hexadecimal(magic, true));

            list.Add("threaded");
            list.Add(threaded.ToString());

            list.Add("debug");
            list.Add(debug.ToString());

            return list.ToString();
        }
        #endregion
    }
}
