/*
 * Class4.cs --
 *
 * Copyright (c) 2007-2012 by Joe Mistachkin.  All rights reserved.
 *
 * See the file "license.terms" for information on usage and redistribution of
 * this file, and for a DISCLAIMER OF ALL WARRANTIES.
 *
 * RCS: @(#) $Id: $
 */

using System;
using System.Collections.Generic;
using Eagle._Attributes;
using Eagle._Components.Public;
using Eagle._Containers.Public;
using Eagle._Interfaces.Public;
using _Plugins = Eagle._Plugins;

namespace Sample
{
    //
    // NOTE: Declare a "custom plugin" class that inherits notify
    //       functionality and implements the appropriate interface(s).
    //
    // FIXME: Always change this GUID.
    //
    [ObjectId("bacdcc28-eeb6-4c30-8293-e3646884b199")]
    [PluginFlags(
        PluginFlags.User | PluginFlags.Notify |
        PluginFlags.NoCommands | PluginFlags.NoPolicies)]
    [NotifyTypes(NotifyType.Script)]
    [NotifyFlags(NotifyFlags.Completed)]
    internal sealed class Class4 : _Plugins.Notify
    {
        #region Public Constructor (Required)
        public Class4(
            IPluginData pluginData
            )
            : base(pluginData)
        {
            //
            // NOTE: Typically, nothing much is done here.  Any non-trivial
            //       initialization should be done in IState.Initialize and
            //       cleaned up in IState.Terminate.
            //
            this.Flags |= Utility.GetPluginFlags(GetType().BaseType) |
                Utility.GetPluginFlags(this); /* HIGHLY RECOMMENDED */
        }
        #endregion

        ////////////////////////////////////////////////////////////////////////

        #region INotify Members (Required)
        /// <summary>
        ///   Receives notifications when an event occurs that the plugin has
        ///   declared it wants to be notified about.
        /// </summary>
        ///
        /// <param name="interpreter">
        ///   The interpreter context we are executing in.
        /// </param>
        ///
        /// <param name="eventArgs">
        ///   Contains data related to the event.  The exact data depends on
        ///   the type of event being processed.
        /// </param>
        /// 
        /// <param name="clientData">
        ///   The extra data supplied for this event, if any.
        /// </param>
        ///
        /// <param name="result">
        ///   Upon success, this may contain an informational message.
        ///   Upon failure, this must contain an appropriate error message.
        /// </param>
        ///
        /// <returns>
        ///   ReturnCode.Ok on success, ReturnCode.Error on failure.
        /// </returns>
        public override ReturnCode Notify(
            Interpreter interpreter,
            IScriptEventArgs eventArgs,
            IClientData clientData,
            ArgumentList arguments,
            ref Result result
            )
        {
            ReturnCode code = ReturnCode.Ok;

            if (eventArgs != null)
            {
                Interpreter eventInterpreter = eventArgs.Interpreter;

                if ((eventInterpreter != null) &&
                    (eventArgs.ClientData != null) &&
                    (eventArgs.ClientData.Data != null))
                {
                    if (Utility.HasFlags(eventArgs.Types,
                            NotifyType.Script, true) &&
                        Utility.HasFlags(eventArgs.Flags,
                            NotifyFlags.Completed, true))
                    {
                        IList<object> list =
                            eventArgs.ClientData.Data as IList<object>;

                        if (list != null)
                        {
                            string text;

                            try
                            {
                                text = list[2] as string;

                                if (text != null)
                                    text = text.Substring(
                                        (int)list[3], (int)list[4]);
                            }
                            catch
                            {
                                text = null;
                            }

                            if (text != null)
                            {
                                IInteractiveHost interactiveHost = interpreter.Host;

                                if (interactiveHost != null)
                                    interactiveHost.WriteLine(String.Format(
                                        "{0}: script completed{1}{2}",
                                        GetType().FullName,
                                        Environment.NewLine, text));
                            }
                        }
                    }
                }
            }

            return code;
        }
        #endregion
    }
}
